Command-line interfaces
=======================

This page documents all command-line client interfaces available in ``taurenmd``, referred also as *taurenmd subroutines*. You may wish to read before the :ref:`Usage` page for general examples on how to use ``taurenmd`` for different purposes.


On the ``terminal``, you can access a list of all *taurenmd subroutines* by running::

    taurenmd

You can then access the individual help for each subroutine as follows, for example::

    taurenmd dist -h

where, ``-h`` is optional.

The same help messages can be found in this documentation in the links provided bellow.

taurenmd subroutines
--------------------

This TOC lists all *taurenmd subroutines*, click on each one to read on specific usage examples, and technical documentation.

.. toctree::
   :maxdepth: 1

   cli_distances
   cli_fext
   cli_imagemol
   cli_nosol
   cli_pangle
   cli_report
   cli_rmsd
   cli_rmsf
   cli_rotations
   cli_trajedit
